%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% This is a document/script to solve the pde for the 1d case of z direc %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Loading the data from the csvFile and defining some constants
filename1D = 'Au_CcovZEmin.csv'; % sample datafile
data1D = csvread(filename1D);

eVolt = 1.60218e-19; % conversion factor from eV to J
heV = 4.1357e-15; % planck's constant in eV.s
A2M2 = 1.0e-20; % conversion factor for are from sq. Angstrom to sq m.
mAds = 1.9944e-26; % mass of the adsorbate

% Calculate the kinetic energy coefficient
KE = heV*heV*eVolt/(8*pi*pi*mAds*A2M2)

%% Extracting z and E from data1D
X = data1D(:,1);
E = data1D(:,2)-min(data1D(:,2)); % Energy is referenced to the most stable site
% Obtain max and min for the grid
xMin = min(X);
xMax = max(X);

%% Convert x, y and E into a table and plot to ensure data is loaded properly
T = table(X,E);
V = fit([T.X], T.E, 'cubicinterp');
plot(V, [T.X], T.E)
pause

%% Solving the Schrodinger equation using finite difference
L = xMax; % Eqn solved for -L to +L
n = 51; % number of parts
dx = 2*L/n; % Mesh size
xGrid= -L+dx:dx:L-dx
A = zeros(n-1); % Secular matrix
for i=1:n-1 % Populating the secular matrix
    for j=1:n-1
        if i==j+1|i==j-1
            A(i,j) = -1*KE/dx^2;
        end
    end
    A(i,i) = 2.0*KE/dx^2 + V(xGrid(i));
end

% Solve for eigenvalues
[wfn E] = eig(A);
% save the eigensolutions as lz
lz = zeros(1,n-1);
fprintf('*** Energy eigenvalues upto n = %d ***\n',n);
for i=1:n-1
    fprintf('n=%2d --> E=%15.6f\n',i,E(i,i));
    lz(i) = E(i,i);
pause(1);
end