%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% This is a document/script to solve the pde for the 2d case of surface %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Loading the data from the csvFile and defining some constants
filename2D = 'Au_C_XY_1X1.csv'; % CSV datafile
data2D = csvread(filename2D);
eVolt = 1.60218e-19; % conversion factor from eV to J
heV = 4.1357e-15; % planck's constant in eV.s
A2M2 = 1.0e-20; % conversion factor for are from sq. Angstrom to sq m.
mAds = 1.9944e-26; % mass of the adsorbate

% Calculate the kinetic energy coefficient
KE = heV*heV*eVolt/(8*pi*pi*mAds*A2M2)

%% Extracting x,y and E from data2D
%% Note that x is the vertical direction y, z are in-plane directions
X = data2D(:,2);
Y = data2D(:,3);
E = data2D(:,4)-min(data2D(:,4)); % Energy is referenced to the most stable site
% Obtain max and min for the grid
xMin = min(X);
xMax = max(X);
yMin = min(Y);
yMax = max(Y);

%% Convert x, y and E into a table and plotting to ensure that the data
%% is loaded correctly
T = table(X,Y,E);
V = fit([T.X, T.Y], T.E, 'cubicinterp');
plot(V, [T.X, T.Y], T.E)
pause

%% Setting up the 2D solver
model = createpde()
% display the range of the two dimensions
disp([xMin xMax])
disp([yMin yMax])
pderect([xMin xMax yMin yMax])
%% Adjust the scale on the pde figure:
% options > Axis Limit... > Auto > Close
disp('Adjust the Grid space')
pause
%% Export the variables from the pde set up
% Draw > Export Geometry Description, Set Formula Labels
disp('Pull out the geometry')
pause

% Setting up all the variable for solving the 2D Schrodinger equation
g = decsg(gd,sf,ns);
pg = geometryFromEdges(model,g);
applyBoundaryCondition(model,'Edge',1:4,'r',0,'h',1);

% Definging Coefficients for the eigenmodes pde available at PDE >
% PDE_specification... > Eigenmodes
c = KE;
d = 1;
% Creating a mesh for solving the Schrodinger equation
mesh = generateMesh(model,'Hmax',0.05);
% a is defined from an external file
a = 'acoeffC(x,y)';

% range of energy over which energy solutions are explored
r = [0, 0.5];
% solve for eigenfunctions (v) and eigenvalue energy states (l)
[v, l] = pdeeig(model,c,a,d,r);
